==> mutual_credit-6.0.x-dev.tar.gz: mutual_credit/src/Entity/ListBuilder/TransactionListBuilder.php <==
<?php

namespace Drupal\mcapi\Entity\ListBuilder;

use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Build a listing of transactions.
 *
 * @ingroup entity_api
 * @todo inject currentuser
 */
class TransactionListBuilder extends EntityListBuilder {

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'mc_transaction_collection';
  }

  /**
   * {@inheritDoc}
   */
  public function buildHeader() {
    $header['id'] = '';
    $header['created'] = $this->t('Created');
    $header['payer'] = [
      'data' => $this->t('Payer'),
      'class' => [RESPONSIVE_PRIORITY_MEDIUM],
    ];
    $header['payee'] = [
      'data' => $this->t('Payee'),
      'class' => [RESPONSIVE_PRIORITY_MEDIUM],
    ];
    $header['description'] = $this->t('Description');
    $header['quant'] = $this->t('Quantity', [], ['context' => 'ledger entry']);
    $header['workflow'] = [
      'data' => $this->t('Workflow'),
      'class' => [RESPONSIVE_PRIORITY_LOW],
    ];
    $header['state'] = [
      'data' => $this->t('State'),
      'class' => [RESPONSIVE_PRIORITY_LOW],
    ];
    return $header + parent::buildHeader();
  }
    /**
   * {@inheritDoc}
   */
  public function buildRow(EntityInterface $entity) {
    $actions = parent::buildRow($entity);
    if ($actions = parent::buildRow($entity)) {
      $row['id'] = '#'.$entity->xid->value;
      $row['created']['data'] = $entity->created->view(['label' => 'hidden']);
      $row['payer']['data'] = $entity->payer->toLink();
      $row['payee']['data'] = $entity->payee->toLink();
      $row['description']['data'] = $entity->description;
      $row['quant']['data'] = $entity->quant;
      $row['workflow']['data'] = $entity->workflow->entity->label();
      $row['state']['data'] = $entity->state->value;
      $row += $actions;
    }
    return $row;
  }

  /**
   * {@inheritDoc}
   *
   * Derive the operations from the current user and the transaction workflow state
   *
   * This looks at the workflow paths available and makes an 'operation' for each.
   * @todo why are the operations for a new transaction handled separately?
   * @todo Why not put the view transition here as long as it is not cached?
   */
  public function getDefaultOperations(EntityInterface $transaction) {
    $links = [];
    $current_user = \Drupal::currentUser();
    if (!$transaction->isNew() and isset($transaction->workflow->entity->states[$transaction->state->value])) {
      $role = '';
      // derive the other links from the workflow.
      if ($transaction->payee->getOwnerId() == $current_user->id()) {
        $role = 'payee';
      }
      elseif ($transaction->payer->getOwnerId() == $current_user->id()) {
        $role = 'payer';
      }
      // Drupal cannot be admin for a remote transaction.
      // All operations are workflow transitions.
      // This must correspond with the route's permission. See TransactionAccessControlHandler
      $state_info = $transaction->workflow->entity->states[$transaction->state->value];
      foreach (array_filter($state_info) as $dest_state_id => $info) {
        // Permission check according to the workflow directly.
        if ($role == $info['actor'] or $current_user->hasPermission('manage mcapi')) {
          $links[$dest_state_id] = [
            'title' => $info['label'],
            'url' => Url::fromRoute(
              'entity.mc_transaction.transition',
              ['mc_transaction' => $transaction->id(), 'dest_state' => $dest_state_id],
              ['query' => ['destination' => Url::fromRoute('<current>')->toString()]]
            )
          ];
        }
      }
    }
    // In addition to all the credcom workflow operations there is also 'delete'.
    if (\Drupal::config('mcapi.settings')->get('delete_transactions') and $account->hasPermission('manage mcapi')) {
      $links['delete'] = [
        'title' => $this->t('Delete'),
        'url' => Url::fromRoute(
          'entity.mc_transaction.transition',
          ['mc_transaction' => $transaction->id(), 'dest_state' => 'deleted'], // Actually not a state!
        )
      ];
    }
    return $links;
  }

}

==> mutual_credit-6.1.x-dev.tar.gz: mutual_credit/src/Entity/ListBuilder/TransactionListBuilder.php <==
<?php

namespace Drupal\mcapi\Entity\ListBuilder;

use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\Query\QueryInterface;

/**
 * Build a listing of transactions. This is only used if views is not installed.
 *
 * @ingroup entity_api
 * @todo inject currentuser
 */
class TransactionListBuilder extends EntityListBuilder {

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'mc_transaction_collection';
  }

  /**
   * {@inheritDoc}
   */
  public function buildHeader() {
    $header['id'] = '';
    $header['created'] = $this->t('Created');
    $header['payer'] = [
      'data' => $this->t('Payer'),
      'class' => [RESPONSIVE_PRIORITY_MEDIUM],
    ];
    $header['payee'] = [
      'data' => $this->t('Payee'),
      'class' => [RESPONSIVE_PRIORITY_MEDIUM],
    ];
    $header['description'] = $this->t('Description');
    $header['quant'] = $this->t('Quantity', [], ['context' => 'ledger entry']);
    $header['workflow'] = [
      'data' => $this->t('Workflow'),
      'class' => [RESPONSIVE_PRIORITY_LOW],
    ];
    $header['state'] = [
      'data' => $this->t('State'),
      'class' => [RESPONSIVE_PRIORITY_LOW],
    ];
    return $header + parent::buildHeader();
  }
  /**
   * {@inheritDoc}
   */
  public function buildRow(EntityInterface $entity) {
    $actions = parent::buildRow($entity);
    if ($actions = parent::buildRow($entity)) {
      $row['id'] = '#'.$entity->xid->value;
      $row['created']['data'] = $entity->created->view(['label' => 'hidden']);
      $row['payer']['data'] = $entity->payer->toLink();
      $row['payee']['data'] = $entity->payee->toLink();
      $row['description']['data'] = $entity->description;
      $row['quant']['data'] = \Drupal::service('mcapi.currency_formatter')->format($entity->quant);
      $row['workflow']['data'] = $entity->workflow->entity->label();
      $row['state']['data'] = \Drupal\mcapi\Plugin\Field\FieldType\McState::stateNames()[$entity->state->value];
      $row += $actions;
    }
    return $row;
  }

  /**
   * {@inheritDoc}
   * List in descending order.
   */
  protected function getEntityListQuery(): QueryInterface {
    $query = parent::getEntityListQuery();
    $query->sort($this->entityType->getKey(static::SORT_KEY), 'DESC');
    return $query;
  }

  /**
   * {@inheritDoc}
   *
   * Derive the operations from the current user and the transaction workflow state
   *
   * This looks at the workflow paths available and makes an 'operation' for each.
   * @todo why are the operations for a new transaction handled separately?
   */
  public function getDefaultOperations(EntityInterface $transaction) {
    return $transaction->workflow->links();
  }

}
